# [1.1.0](https://github.com/obviyus/uv-up/compare/v1.0.0...v1.1.0) (2025-08-08)


### Features

* enhance version fetching and project management ([3d41469](https://github.com/obviyus/uv-up/commit/3d414694504f5fcf66b52c1383924b8531671c3e))
* update package.json for improved development workflow ([9e453f3](https://github.com/obviyus/uv-up/commit/9e453f34c939cc7c796f93b18409e7f2ea37c424))

# 1.0.0 (2025-07-24)


### Features

* add bun types ([e9e8ff5](https://github.com/obviyus/uv-up/commit/e9e8ff5dd8f931f33597bf61a9d0057ab01921f9))
* enhance dependency parsing and version updating logic ([1182d3f](https://github.com/obviyus/uv-up/commit/1182d3f953f7f22f01109a173c157bafb4707cba))
* prefer to use Bun's in built features more ([1ef89a8](https://github.com/obviyus/uv-up/commit/1ef89a815e3f1133902012ab9f0b321d42a9c726))
* re-work confirm UI to be tabular ([86d738d](https://github.com/obviyus/uv-up/commit/86d738de576b2de61bc26d83b3c5d1d40b8f94d3))
* refactor index.tsx for improved type safety and UI components ([4d9885a](https://github.com/obviyus/uv-up/commit/4d9885a2022cf3ff88de9185fcd97efd4843781e))
* simplify code ([8a7d37f](https://github.com/obviyus/uv-up/commit/8a7d37f7b9eed0b032dac717e5f4b0fcb6aab385))
* use tablular UI instead ([a8c0bde](https://github.com/obviyus/uv-up/commit/a8c0bde4245c0ecd6418678df269229ce69e8e89))
